#[non_exhaustive]pub enum ErrorContext {
File,
Prologue,
Frame {
sequence: u64,
},
Prefix,
Header,
Payload,
Trailer,
}Expand description
The region of a file an error was detected in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
File
The file as a whole, rather than one of its structures.
Prologue
Frame
Prefix
Header
Payload
Trailer