#[non_exhaustive]pub enum RecoveryAction {
None,
TruncateIncompleteTail,
}Expand description
The action a recovery inspection recommends.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
The file ends at a complete, structurally validated frame boundary.
TruncateIncompleteTail
The file ends inside one final data frame and may be truncated safely.