#[non_exhaustive]pub struct RecoverySummary { /* private fields */ }Expand description
The result of successfully repairing one incomplete final data frame.
Implementations
Sourceimpl RecoverySummary
impl RecoverySummary
Sourcepub fn original_file_size(&self) -> u64
pub fn original_file_size(&self) -> u64
The file length observed before the repair.
Sourcepub fn repaired_file_size(&self) -> u64
pub fn repaired_file_size(&self) -> u64
The file length after truncation and post-repair validation.
Sourcepub fn bytes_removed(&self) -> u64
pub fn bytes_removed(&self) -> u64
The number of bytes removed from the incomplete tail.