pub struct ValidationOptions { /* private fields */ }Expand description
Options controlling Acta validation.
The fields are private so new validation controls can be added without exposing an unvalidated configuration structure.
Implementations
Sourceimpl ValidationOptions
impl ValidationOptions
Sourcepub fn with_level(self, level: ValidationLevel) -> Self
pub fn with_level(self, level: ValidationLevel) -> Self
Return these options with the requested validation level.
Sourcepub fn with_limits(self, limits: Limits) -> Self
pub fn with_limits(self, limits: Limits) -> Self
Return these options with caller-supplied resource limits.
Sourcepub fn level(&self) -> ValidationLevel
pub fn level(&self) -> ValidationLevel
The selected validation level.