ValidationOptions

Struct ValidationOptions 

pub struct ValidationOptions { /* private fields */ }
Options controlling Acta validation.

The fields are private so new validation controls can be added without exposing an unvalidated configuration structure.

Implementations

Source

impl ValidationOptions

pub fn with_level(self, level: ValidationLevel) -> Self

Return these options with the requested validation level.

pub fn with_limits(self, limits: Limits) -> Self

Return these options with caller-supplied resource limits.

pub fn level(&self) -> ValidationLevel

The selected validation level.

pub fn limits(&self) -> Limits

The resource limits applied during validation.